Index: third_party/WebKit/Source/core/events/EventTarget.h |
diff --git a/third_party/WebKit/Source/core/events/EventTarget.h b/third_party/WebKit/Source/core/events/EventTarget.h |
index 8c9e9e96b36acea69964697b9a0828717f4905f8..fa1cd9ffb90cb9fb7eb496a1072950f1029118aa 100644 |
--- a/third_party/WebKit/Source/core/events/EventTarget.h |
+++ b/third_party/WebKit/Source/core/events/EventTarget.h |
@@ -102,7 +102,7 @@ public: |
// very strange compiler errors. |
// - If you added an onfoo attribute, use DEFINE_ATTRIBUTE_EVENT_LISTENER(foo) |
// in your class declaration. |
// - Override EventTarget::interfaceName() and executionContext(). The former |
// will typically return EventTargetNames::YourClassName. The latter will |
// return ActiveDOMObject::executionContext (if you are an ActiveDOMObject) |
// or the document you're in. |
@@ -123,7 +123,7 @@ public: |
#endif |
virtual const AtomicString& interfaceName() const = 0; |
- virtual ExecutionContext* executionContext() const = 0; |
+ virtual ExecutionContext* getExecutionContext() const = 0; |
virtual Node* toNode(); |
virtual const LocalDOMWindow* toDOMWindow() const; |
@@ -102,7 +102,7 @@ public: |
// - If you added an onfoo attribute, use DEFINE_ATTRIBUTE_EVENT_LISTENER(foo) |
// in your class declaration. |
-// - Override EventTarget::interfaceName() and executionContext(). The former |
+// - Override EventTarget::interfaceName() and getExecutionContext(). The former |
// will typically return EventTargetNames::YourClassName. The latter will |
// return ActiveDOMObject::executionContext (if you are an ActiveDOMObject) |